@@ -1,5 +1,56 @@
 var NAVTREEINDEX124 =
 {
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428":[3,0,10,32,22,1],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428":[4,0,7,27,21,1],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428a4be3bacfe645091ac948182bee96d057":[3,0,10,32,22,1,1],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428a4be3bacfe645091ac948182bee96d057":[4,0,7,27,21,1,1],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428a6d3e20de29663240a282c8ed1c2d848a":[3,0,10,32,22,1,0],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428a6d3e20de29663240a282c8ed1c2d848a":[4,0,7,27,21,1,0],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428a9536b0050b13d9abc0c33b0d69b3da73":[3,0,10,32,22,1,2],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428a9536b0050b13d9abc0c33b0d69b3da73":[4,0,7,27,21,1,2],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428ab1097c952062981f1bd712805581e9bf":[3,0,10,32,22,1,3],
+"structzypp_1_1repo_1_1RepoReport.html#a613e8e28e9eeaedfbf84918f8c2ca428ab1097c952062981f1bd712805581e9bf":[4,0,7,27,21,1,3],
+"structzypp_1_1repo_1_1RepoReport.html#a665d08a891a115a66946efd10d2aad03":[3,0,10,32,22,4],
+"structzypp_1_1repo_1_1RepoReport.html#a665d08a891a115a66946efd10d2aad03":[4,0,7,27,21,4],
+"structzypp_1_1repo_1_1RepoType.html":[3,0,10,32,23],
+"structzypp_1_1repo_1_1RepoType.html":[4,0,7,27,22],
+"structzypp_1_1repo_1_1RepoType.html#a3f120be27bd25931a92debeafcfa6cd5":[3,0,10,32,23,5],
+"structzypp_1_1repo_1_1RepoType.html#a3f120be27bd25931a92debeafcfa6cd5":[4,0,7,27,22,5],
+"structzypp_1_1repo_1_1RepoType.html#a52176587b0b1b7755dae27e5e0497353":[3,0,10,32,23,8],
+"structzypp_1_1repo_1_1RepoType.html#a52176587b0b1b7755dae27e5e0497353":[4,0,7,27,22,8],
+"structzypp_1_1repo_1_1RepoType.html#a556bb034a88b505fdc918bdd719e6cd8":[3,0,10,32,23,6],
+"structzypp_1_1repo_1_1RepoType.html#a556bb034a88b505fdc918bdd719e6cd8":[4,0,7,27,22,6],
+"structzypp_1_1repo_1_1RepoType.html#a6907d0947dbd1ff5b6ebe1528e14623e":[3,0,10,32,23,1],
+"structzypp_1_1repo_1_1RepoType.html#a6907d0947dbd1ff5b6ebe1528e14623e":[4,0,7,27,22,1],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03":[3,0,10,32,23,0],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03":[4,0,7,27,22,0],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03a12091aa8d71de757c61b2fea14496d91":[3,0,10,32,23,0,1],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03a12091aa8d71de757c61b2fea14496d91":[4,0,7,27,22,0,1],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03a9215e92bab67de896ccaa0672bcafab5":[3,0,10,32,23,0,0],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03a9215e92bab67de896ccaa0672bcafab5":[4,0,7,27,22,0,0],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03a98020434ba973c12ecc88323262a7e1f":[3,0,10,32,23,0,2],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03a98020434ba973c12ecc88323262a7e1f":[4,0,7,27,22,0,2],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03ae15559924c4247e0108006114342dfc1":[3,0,10,32,23,0,3],
+"structzypp_1_1repo_1_1RepoType.html#a6d69173d8377c1f509e165f72be47f03ae15559924c4247e0108006114342dfc1":[4,0,7,27,22,0,3],
+"structzypp_1_1repo_1_1RepoType.html#a881cb7d3aebc7e547f52dce99bb04b11":[3,0,10,32,23,2],
+"structzypp_1_1repo_1_1RepoType.html#a881cb7d3aebc7e547f52dce99bb04b11":[4,0,7,27,22,2],
+"structzypp_1_1repo_1_1RepoType.html#aa3093c699ff6a71fff8e856d7a2ce701":[3,0,10,32,23,3],
+"structzypp_1_1repo_1_1RepoType.html#aa3093c699ff6a71fff8e856d7a2ce701":[4,0,7,27,22,3],
+"structzypp_1_1repo_1_1RepoType.html#ad73123b7a5b33d9020335c2d4e6a31c9":[3,0,10,32,23,4],
+"structzypp_1_1repo_1_1RepoType.html#ad73123b7a5b33d9020335c2d4e6a31c9":[4,0,7,27,22,4],
+"structzypp_1_1repo_1_1RepoType.html#ae2ad4b838365110a1fa4d36ec939242c":[3,0,10,32,23,7],
+"structzypp_1_1repo_1_1RepoType.html#ae2ad4b838365110a1fa4d36ec939242c":[4,0,7,27,22,7],
+"structzypp_1_1repo_1_1RepoType.html#aed61b8e66dad5ee25d14bffce34b9f79":[3,0,10,32,23,11],
+"structzypp_1_1repo_1_1RepoType.html#aed61b8e66dad5ee25d14bffce34b9f79":[4,0,7,27,22,11],
+"structzypp_1_1repo_1_1RepoType.html#aee92ae00c59944de540955bdbca0876d":[3,0,10,32,23,10],
+"structzypp_1_1repo_1_1RepoType.html#aee92ae00c59944de540955bdbca0876d":[4,0,7,27,22,10],
+"structzypp_1_1repo_1_1RepoType.html#af1748a4b8f2bef33b15ab155714100c6":[3,0,10,32,23,9],
+"structzypp_1_1repo_1_1RepoType.html#af1748a4b8f2bef33b15ab155714100c6":[4,0,7,27,22,9],
+"structzypp_1_1repo_1_1RepoVarExpand.html":[3,0,10,32,25],
+"structzypp_1_1repo_1_1RepoVarExpand.html":[4,0,7,27,24],
+"structzypp_1_1repo_1_1RepoVarExpand.html#a61cf85c498dcfd51cadb80f2cb0522e5":[3,0,10,32,25,0],
+"structzypp_1_1repo_1_1RepoVarExpand.html#a61cf85c498dcfd51cadb80f2cb0522e5":[4,0,7,27,24,0],
+"structzypp_1_1repo_1_1RepoVarExpand.html#ad06e9982b7f7b08b2ea375e73665f051":[3,0,10,32,25,2],
 "structzypp_1_1repo_1_1RepoVarExpand.html#ad06e9982b7f7b08b2ea375e73665f051":[4,0,7,27,24,2],
 "structzypp_1_1repo_1_1RepoVarExpand.html#ad425b8e55fb23bc94082f9bb7563f4d1":[3,0,10,32,25,1],
 "structzypp_1_1repo_1_1RepoVarExpand.html#ad425b8e55fb23bc94082f9bb7563f4d1":[4,0,7,27,24,1],
@@ -198,56 +249,5 @@ var NAVTREEINDEX124 =
 "structzypp_1_1rw__pointer_1_1Scoped.html#ad43f70c9aff3d10108b8f95d95830799":[4,0,7,30,1,4],
 "structzypp_1_1rw__pointer_1_1Shared.html":[3,0,10,36,2],
 "structzypp_1_1rw__pointer_1_1Shared.html":[4,0,7,30,2],
-"structzypp_1_1rw__pointer_1_1Shared.html#a563b4e0759f4fd5e8ea9a3f1d24ea436":[3,0,10,36,2,0],
-"structzypp_1_1rw__pointer_1_1Shared.html#a563b4e0759f4fd5e8ea9a3f1d24ea436":[4,0,7,30,2,0],
-"structzypp_1_1rw__pointer_1_1Shared.html#a8ba42e941395371c734da07cb72885e4":[3,0,10,36,2,5],
-"structzypp_1_1rw__pointer_1_1Shared.html#a8ba42e941395371c734da07cb72885e4":[4,0,7,30,2,5],
-"structzypp_1_1rw__pointer_1_1Shared.html#a998f513a931ced961c0d5491baf1e0dd":[3,0,10,36,2,1],
-"structzypp_1_1rw__pointer_1_1Shared.html#a998f513a931ced961c0d5491baf1e0dd":[4,0,7,30,2,1],
-"structzypp_1_1rw__pointer_1_1Shared.html#a9a927f94c1c8e3ae23e06024d460e0aa":[3,0,10,36,2,4],
-"structzypp_1_1rw__pointer_1_1Shared.html#a9a927f94c1c8e3ae23e06024d460e0aa":[4,0,7,30,2,4],
-"structzypp_1_1rw__pointer_1_1Shared.html#aab5f2ba97d3db937ea89f1779d09995f":[3,0,10,36,2,2],
-"structzypp_1_1rw__pointer_1_1Shared.html#aab5f2ba97d3db937ea89f1779d09995f":[4,0,7,30,2,2],
-"structzypp_1_1rw__pointer_1_1Shared.html#afd21c916c4c9d654c7404c3fc8ff1bd1":[3,0,10,36,2,3],
-"structzypp_1_1rw__pointer_1_1Shared.html#afd21c916c4c9d654c7404c3fc8ff1bd1":[4,0,7,30,2,3],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html":[3,0,10,37,5,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html":[4,0,7,31,6,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a1ef9aee4d1d4a99702de9c928b5aca49":[3,0,10,37,5,0,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a1ef9aee4d1d4a99702de9c928b5aca49":[4,0,7,31,6,0,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a207e60bda772a0258b320b15e234967e":[3,0,10,37,5,0,2],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a207e60bda772a0258b320b15e234967e":[4,0,7,31,6,0,2],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2c4a2134c69f32404187eff115ba1b2e":[3,0,10,37,5,0,3],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2c4a2134c69f32404187eff115ba1b2e":[4,0,7,31,6,0,3],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2f39ad34fe96979c3294e1103609ecb9":[3,0,10,37,5,0,1],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2f39ad34fe96979c3294e1103609ecb9":[4,0,7,31,6,0,1],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[3,0,10,37,5,12],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[3,0,10,37,5,0,8],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[4,0,7,31,6,12],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[4,0,7,31,6,0,8],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a85d5449082b598fcc76f5ddcc21159c8":[3,0,10,37,5,0,6],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a85d5449082b598fcc76f5ddcc21159c8":[4,0,7,31,6,0,6],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a8831b9bdd2ca30f821e05bdb7343efc8":[3,0,10,37,5,0,9],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a8831b9bdd2ca30f821e05bdb7343efc8":[4,0,7,31,6,0,9],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a9f5813983a77a400763c0dbd41e38c40":[3,0,10,37,5,0,5],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a9f5813983a77a400763c0dbd41e38c40":[4,0,7,31,6,0,5],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[3,0,10,37,5,10],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[3,0,10,37,5,0,7],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[4,0,7,31,6,10],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[4,0,7,31,6,0,7],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#addbee0aa405fc4b2b745472ec8db59e3":[3,0,10,37,5,0,4],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#addbee0aa405fc4b2b745472ec8db59e3":[4,0,7,31,6,0,4],
-"structzypp_1_1sat_1_1Map_1_1PoolSizeType.html":[3,0,10,37,9,0],
-"structzypp_1_1sat_1_1Map_1_1PoolSizeType.html":[4,0,7,31,10,0],
-"structzypp_1_1sat_1_1SolvableType.html":[3,0,10,37,14],
-"structzypp_1_1sat_1_1SolvableType.html":[4,0,7,31,15],
-"structzypp_1_1sat_1_1SolvableType.html#a001dacc628cc10610127e06e952c854c":[3,0,10,37,14,51],
-"structzypp_1_1sat_1_1SolvableType.html#a001dacc628cc10610127e06e952c854c":[4,0,7,31,15,51],
-"structzypp_1_1sat_1_1SolvableType.html#a0125e3562490368edff76e1cf63728d1":[3,0,10,37,126],
-"structzypp_1_1sat_1_1SolvableType.html#a0125e3562490368edff76e1cf63728d1":[3,0,10,37,14,86],
-"structzypp_1_1sat_1_1SolvableType.html#a0125e3562490368edff76e1cf63728d1":[4,0,7,31,15,86],
-"structzypp_1_1sat_1_1SolvableType.html#a03eaa241a1652c80eed5282d8a6a0289":[3,0,10,37,14,40],
-"structzypp_1_1sat_1_1SolvableType.html#a03eaa241a1652c80eed5282d8a6a0289":[4,0,7,31,15,40],
-"structzypp_1_1sat_1_1SolvableType.html#a06edc857562a30a379ea55c282345ff6":[3,0,10,37,14,67],
-"structzypp_1_1sat_1_1SolvableType.html#a06edc857562a30a379ea55c282345ff6":[4,0,7,31,15,67],
-"structzypp_1_1sat_1_1SolvableType.html#a0d174b6ea5fc70d21addde39e325f71a":[3,0,10,37,14,80]
+"structzypp_1_1rw__pointer_1_1Shared.html#a563b4e0759f4fd5e8ea9a3f1d24ea436":[3,0,10,36,2,0]
 };
