@@ -1,5 +1,56 @@
 var NAVTREEINDEX125 =
 {
+"structzypp_1_1rw__pointer_1_1Shared.html#a563b4e0759f4fd5e8ea9a3f1d24ea436":[4,0,7,30,2,0],
+"structzypp_1_1rw__pointer_1_1Shared.html#a8ba42e941395371c734da07cb72885e4":[3,0,10,36,2,5],
+"structzypp_1_1rw__pointer_1_1Shared.html#a8ba42e941395371c734da07cb72885e4":[4,0,7,30,2,5],
+"structzypp_1_1rw__pointer_1_1Shared.html#a998f513a931ced961c0d5491baf1e0dd":[3,0,10,36,2,1],
+"structzypp_1_1rw__pointer_1_1Shared.html#a998f513a931ced961c0d5491baf1e0dd":[4,0,7,30,2,1],
+"structzypp_1_1rw__pointer_1_1Shared.html#a9a927f94c1c8e3ae23e06024d460e0aa":[3,0,10,36,2,4],
+"structzypp_1_1rw__pointer_1_1Shared.html#a9a927f94c1c8e3ae23e06024d460e0aa":[4,0,7,30,2,4],
+"structzypp_1_1rw__pointer_1_1Shared.html#aab5f2ba97d3db937ea89f1779d09995f":[3,0,10,36,2,2],
+"structzypp_1_1rw__pointer_1_1Shared.html#aab5f2ba97d3db937ea89f1779d09995f":[4,0,7,30,2,2],
+"structzypp_1_1rw__pointer_1_1Shared.html#afd21c916c4c9d654c7404c3fc8ff1bd1":[3,0,10,36,2,3],
+"structzypp_1_1rw__pointer_1_1Shared.html#afd21c916c4c9d654c7404c3fc8ff1bd1":[4,0,7,30,2,3],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html":[3,0,10,37,5,0],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html":[4,0,7,31,6,0],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a1ef9aee4d1d4a99702de9c928b5aca49":[3,0,10,37,5,0,0],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a1ef9aee4d1d4a99702de9c928b5aca49":[4,0,7,31,6,0,0],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a207e60bda772a0258b320b15e234967e":[3,0,10,37,5,0,2],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a207e60bda772a0258b320b15e234967e":[4,0,7,31,6,0,2],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2c4a2134c69f32404187eff115ba1b2e":[3,0,10,37,5,0,3],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2c4a2134c69f32404187eff115ba1b2e":[4,0,7,31,6,0,3],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2f39ad34fe96979c3294e1103609ecb9":[3,0,10,37,5,0,1],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2f39ad34fe96979c3294e1103609ecb9":[4,0,7,31,6,0,1],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[3,0,10,37,5,12],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[3,0,10,37,5,0,8],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[4,0,7,31,6,12],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a667903d05ecd995905d567f5a6dbf2bc":[4,0,7,31,6,0,8],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a85d5449082b598fcc76f5ddcc21159c8":[3,0,10,37,5,0,6],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a85d5449082b598fcc76f5ddcc21159c8":[4,0,7,31,6,0,6],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a8831b9bdd2ca30f821e05bdb7343efc8":[3,0,10,37,5,0,9],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a8831b9bdd2ca30f821e05bdb7343efc8":[4,0,7,31,6,0,9],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a9f5813983a77a400763c0dbd41e38c40":[3,0,10,37,5,0,5],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a9f5813983a77a400763c0dbd41e38c40":[4,0,7,31,6,0,5],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[3,0,10,37,5,10],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[3,0,10,37,5,0,7],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[4,0,7,31,6,10],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#abf565bd02968088a346b63e6a68c679a":[4,0,7,31,6,0,7],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#addbee0aa405fc4b2b745472ec8db59e3":[3,0,10,37,5,0,4],
+"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#addbee0aa405fc4b2b745472ec8db59e3":[4,0,7,31,6,0,4],
+"structzypp_1_1sat_1_1Map_1_1PoolSizeType.html":[3,0,10,37,9,0],
+"structzypp_1_1sat_1_1Map_1_1PoolSizeType.html":[4,0,7,31,10,0],
+"structzypp_1_1sat_1_1SolvableType.html":[3,0,10,37,14],
+"structzypp_1_1sat_1_1SolvableType.html":[4,0,7,31,15],
+"structzypp_1_1sat_1_1SolvableType.html#a001dacc628cc10610127e06e952c854c":[3,0,10,37,14,51],
+"structzypp_1_1sat_1_1SolvableType.html#a001dacc628cc10610127e06e952c854c":[4,0,7,31,15,51],
+"structzypp_1_1sat_1_1SolvableType.html#a0125e3562490368edff76e1cf63728d1":[3,0,10,37,126],
+"structzypp_1_1sat_1_1SolvableType.html#a0125e3562490368edff76e1cf63728d1":[3,0,10,37,14,86],
+"structzypp_1_1sat_1_1SolvableType.html#a0125e3562490368edff76e1cf63728d1":[4,0,7,31,15,86],
+"structzypp_1_1sat_1_1SolvableType.html#a03eaa241a1652c80eed5282d8a6a0289":[3,0,10,37,14,40],
+"structzypp_1_1sat_1_1SolvableType.html#a03eaa241a1652c80eed5282d8a6a0289":[4,0,7,31,15,40],
+"structzypp_1_1sat_1_1SolvableType.html#a06edc857562a30a379ea55c282345ff6":[3,0,10,37,14,67],
+"structzypp_1_1sat_1_1SolvableType.html#a06edc857562a30a379ea55c282345ff6":[4,0,7,31,15,67],
+"structzypp_1_1sat_1_1SolvableType.html#a0d174b6ea5fc70d21addde39e325f71a":[3,0,10,37,14,80],
 "structzypp_1_1sat_1_1SolvableType.html#a0d174b6ea5fc70d21addde39e325f71a":[4,0,7,31,15,80],
 "structzypp_1_1sat_1_1SolvableType.html#a116ade6dcedaf319ea948605c1eabab1":[3,0,10,37,14,49],
 "structzypp_1_1sat_1_1SolvableType.html#a116ade6dcedaf319ea948605c1eabab1":[4,0,7,31,15,49],
@@ -198,56 +249,5 @@ var NAVTREEINDEX125 =
 "structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a2b2186afd407aeb7bb29091866550f4a":[3,0,10,37,17,0,0],
 "structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a2b2186afd407aeb7bb29091866550f4a":[4,0,7,31,18,0,0],
 "structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a887f6d1717de3a108f0f3abbcdb09577":[3,0,10,37,17,0,2],
-"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a887f6d1717de3a108f0f3abbcdb09577":[4,0,7,31,18,0,2],
-"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#ad0783e266a3bc9e9a323a2f874b541e0":[3,0,10,37,17,0,3],
-"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#ad0783e266a3bc9e9a323a2f874b541e0":[4,0,7,31,18,0,3],
-"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#afb6bedc5ff523638ecb94fb9c82162cc":[3,0,10,37,17,0,1],
-"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#afb6bedc5ff523638ecb94fb9c82162cc":[4,0,7,31,18,0,1],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html":[3,0,10,37,17,1],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html":[4,0,7,31,18,1],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06108d5f1a6809bc7b2a6966dbc885e3":[3,0,10,37,17,1,26],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06108d5f1a6809bc7b2a6966dbc885e3":[4,0,7,31,18,1,26],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06544e5571a14fb6c01d8f3e4095f99b":[3,0,10,37,17,1,4],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06544e5571a14fb6c01d8f3e4095f99b":[4,0,7,31,18,1,4],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06a03c2fb0177db088d70efac27553ca":[3,0,10,37,17,1,39],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06a03c2fb0177db088d70efac27553ca":[4,0,7,31,18,1,39],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a0748bd066790bf20eb21f915ad5bcd48":[3,0,10,37,17,1,19],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a0748bd066790bf20eb21f915ad5bcd48":[4,0,7,31,18,1,19],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a15945fca1fd86ebf2b84616cf991062d":[3,0,10,37,17,1,2],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a15945fca1fd86ebf2b84616cf991062d":[4,0,7,31,18,1,2],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a1f9ef3e918b04fc5d3aed4dcb81bcc4b":[3,0,10,37,17,1,23],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a1f9ef3e918b04fc5d3aed4dcb81bcc4b":[4,0,7,31,18,1,23],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a2105091bd90311f43d4e45da9dedf462":[3,0,10,37,17,1,9],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a2105091bd90311f43d4e45da9dedf462":[4,0,7,31,18,1,9],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a2d8db8b094522adaf78e821355340ce3":[3,0,10,37,17,1,1],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a2d8db8b094522adaf78e821355340ce3":[4,0,7,31,18,1,1],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a2e12fd76776bf4bc6b76c4a97a12b42b":[3,0,10,37,17,1,13],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a2e12fd76776bf4bc6b76c4a97a12b42b":[4,0,7,31,18,1,13],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a3311835062857d1d5477a4639637bac2":[3,0,10,37,17,1,21],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a3311835062857d1d5477a4639637bac2":[4,0,7,31,18,1,21],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a3d348ad8929c60863656173914217e6e":[3,0,10,37,17,1,44],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a3d348ad8929c60863656173914217e6e":[4,0,7,31,18,1,44],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a3ff6d0a9268c7aae21624b0e1eee37be":[3,0,10,37,17,1,18],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a3ff6d0a9268c7aae21624b0e1eee37be":[4,0,7,31,18,1,18],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a405850897a6b0223bf43593a2509d3cc":[3,0,10,37,17,1,41],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a405850897a6b0223bf43593a2509d3cc":[4,0,7,31,18,1,41],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a4118272146a67471a9022fab31a28012":[3,0,10,37,17,1,40],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a4118272146a67471a9022fab31a28012":[4,0,7,31,18,1,40],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a4a7fc958175550a893e24531bd9ecb18":[3,0,10,37,17,1,36],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a4a7fc958175550a893e24531bd9ecb18":[4,0,7,31,18,1,36],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a516f5c9f07ed537c32bba5aedcabe49b":[3,0,10,37,17,1,5],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a516f5c9f07ed537c32bba5aedcabe49b":[4,0,7,31,18,1,5],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a529814b2f8ff7056e654a1a7c91f18a2":[3,0,10,37,17,1,33],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a529814b2f8ff7056e654a1a7c91f18a2":[4,0,7,31,18,1,33],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a589893893c8a92dc47a079aaa3b4cdf3":[3,0,10,37,17,1,20],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a589893893c8a92dc47a079aaa3b4cdf3":[4,0,7,31,18,1,20],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a5ab6e9184efb4aaf9c7e01d205ec8246":[3,0,10,37,17,1,8],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a5ab6e9184efb4aaf9c7e01d205ec8246":[4,0,7,31,18,1,8],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a614b6f314e2908129a01e2983efb07fb":[3,0,10,37,17,1,3],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a614b6f314e2908129a01e2983efb07fb":[4,0,7,31,18,1,3],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a6165d82d23c90f9d85882b8c147b36a6":[3,0,10,37,17,1,28],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a6165d82d23c90f9d85882b8c147b36a6":[4,0,7,31,18,1,28],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7b627779eca352107baab7d4c711a5dd":[3,0,10,37,17,1,34],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7b627779eca352107baab7d4c711a5dd":[4,0,7,31,18,1,34],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7cecdd94f93d084e1aeb8a66ef9fc463":[3,0,10,37,17,1,38]
+"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a887f6d1717de3a108f0f3abbcdb09577":[4,0,7,31,18,0,2]
 };
