@@ -1,5 +1,56 @@
 var NAVTREEINDEX132 =
 {
+"structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html#a91c8dfd6b2be5797693b71e268b92d5d":[4,0,9,80,2,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html":[3,0,13,118,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html":[4,0,9,80,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#a22dde46a05a23d9606a519a7578e7455":[3,0,13,118,3,2],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#a22dde46a05a23d9606a519a7578e7455":[4,0,9,80,3,2],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#aba1b459e0df35418dc8d728bc6ba946e":[3,0,13,118,3,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#aba1b459e0df35418dc8d728bc6ba946e":[4,0,9,80,3,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#ad9448873c442a109ac347a0a74c42549":[3,0,13,118,3,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#ad9448873c442a109ac347a0a74c42549":[4,0,9,80,3,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#af0920720763b320f2d82396a1112d971":[3,0,13,118,3,1],
+"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#af0920720763b320f2d82396a1112d971":[4,0,9,80,3,1],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html":[3,0,13,118,4],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html":[4,0,9,80,4],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a2325a771118296af7315f3ddca14a088":[3,0,13,118,4,10],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a2325a771118296af7315f3ddca14a088":[4,0,9,80,4,10],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a4cd9e6a27e064d0f5dcf639b9f74190e":[3,0,13,118,4,6],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a4cd9e6a27e064d0f5dcf639b9f74190e":[4,0,9,80,4,6],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a572bf76e76041db3bb7c5e12600f43b3":[3,0,13,118,4,5],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a572bf76e76041db3bb7c5e12600f43b3":[4,0,9,80,4,5],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a7bb224fb04b4f18d22235923961dba93":[3,0,13,118,4,4],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a7bb224fb04b4f18d22235923961dba93":[4,0,9,80,4,4],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a88c9de89b840b56a6c32ada9851528fa":[3,0,13,118,4,8],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a88c9de89b840b56a6c32ada9851528fa":[4,0,9,80,4,8],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a891ad1ef4e6491defa24d9c6ac0cbdcc":[3,0,13,118,4,7],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a891ad1ef4e6491defa24d9c6ac0cbdcc":[4,0,9,80,4,7],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a96768583275952d5f757958b81ff2783":[3,0,13,118,4,1],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a96768583275952d5f757958b81ff2783":[4,0,9,80,4,1],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#aae93973ae75326d29c7f182a1de3b344":[3,0,13,118,4,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#aae93973ae75326d29c7f182a1de3b344":[4,0,9,80,4,0],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#ab680123fe5c754475d6426bcf76019dc":[3,0,13,118,4,9],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#ab680123fe5c754475d6426bcf76019dc":[4,0,9,80,4,9],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#ad0061d13508f1eccf0874ea619f72f6a":[3,0,13,118,4,2],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#ad0061d13508f1eccf0874ea619f72f6a":[4,0,9,80,4,2],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#ae88982c3031e895508e56319b5cb51de":[3,0,13,118,4,3],
+"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#ae88982c3031e895508e56319b5cb51de":[4,0,9,80,4,3],
+"structzyppng_1_1NetworkRequest_1_1Timings.html":[3,0,13,114,0],
+"structzyppng_1_1NetworkRequest_1_1Timings.html":[4,0,9,76,0],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a06725278538d7322e7c54b623b8fef6d":[3,0,13,114,0,2],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a06725278538d7322e7c54b623b8fef6d":[4,0,9,76,0,2],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a3d8cbdcef6995c534ab2597442a03257":[3,0,13,114,0,5],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a3d8cbdcef6995c534ab2597442a03257":[4,0,9,76,0,5],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a5d4690311b66bb2b0367d277464cafb9":[3,0,13,114,0,3],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a5d4690311b66bb2b0367d277464cafb9":[4,0,9,76,0,3],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a71a358df029c5a4ec20d471b0c39602f":[3,0,13,114,0,4],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a71a358df029c5a4ec20d471b0c39602f":[4,0,9,76,0,4],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a8ca2aa1b869adafc0a665c6b5ccf44a4":[3,0,13,114,0,0],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#a8ca2aa1b869adafc0a665c6b5ccf44a4":[4,0,9,76,0,0],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#aba267155dab51bcf9abe2659b28a9f81":[3,0,13,114,0,1],
+"structzyppng_1_1NetworkRequest_1_1Timings.html#aba267155dab51bcf9abe2659b28a9f81":[4,0,9,76,0,1],
+"structzyppng_1_1Pipe.html":[3,0,13,120],
+"structzyppng_1_1Pipe.html":[4,0,9,82],
 "structzyppng_1_1Pipe.html#a2f52c3c5755943270c3533d2108ec22e":[3,0,13,120,0],
 "structzyppng_1_1Pipe.html#a2f52c3c5755943270c3533d2108ec22e":[4,0,9,82,0],
 "structzyppng_1_1Pipe.html#a31ec2aa48ba7781ffc996db8196f6d88":[3,0,13,120,1],
@@ -198,56 +249,5 @@ var NAVTREEINDEX132 =
 "structzyppng_1_1SocketPrivate_1_1ConnectingState.html#abd8879f0c0b6893fccd69dc8e9e61cc3":[4,0,9,124,3,4],
 "structzyppng_1_1SocketPrivate_1_1ConnectingState.html#ac7223c9693edf6d570441f1092628cf1":[3,0,13,162,3,0],
 "structzyppng_1_1SocketPrivate_1_1ConnectingState.html#ac7223c9693edf6d570441f1092628cf1":[4,0,9,124,3,0],
-"structzyppng_1_1SocketPrivate_1_1ConnectingState.html#af49a004a50dcb37b52aae6ce05099e56":[3,0,13,162,3,2],
-"structzyppng_1_1SocketPrivate_1_1ConnectingState.html#af49a004a50dcb37b52aae6ce05099e56":[4,0,9,124,3,2],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html":[3,0,13,162,4],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html":[4,0,9,124,4],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html#aedf0a23e304986ec54ca24bb1f219322":[3,0,13,162,4,0],
-"structzyppng_1_1SocketPrivate_1_1InitialState.html#aedf0a23e304986ec54ca24bb1f219322":[4,0,9,124,4,0],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html":[3,0,13,162,5],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html":[4,0,9,124,5],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a2c4c0e2d5b3f1867bf5652eb43cc87de":[3,0,13,162,5,0],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a2c4c0e2d5b3f1867bf5652eb43cc87de":[4,0,9,124,5,0],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a66af95d8e8fde474c9e27806114c12dc":[3,0,13,162,5,1],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a66af95d8e8fde474c9e27806114c12dc":[4,0,9,124,5,1],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[3,0,13,162,5,3],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[4,0,9,124,5,3],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[3,0,13,162,5,2],
-"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[4,0,9,124,5,2],
-"structzyppng_1_1Statemachine_1_1__InitialState.html":[3,0,13,163,0],
-"structzyppng_1_1Statemachine_1_1__InitialState.html":[4,0,9,125,0],
-"structzyppng_1_1SyncOp.html":[3,0,13,168],
-"structzyppng_1_1SyncOp.html":[4,0,9,130],
-"structzyppng_1_1SyncOp.html#afea6bb61a58b97227d8a9dc2cdb67601":[3,0,13,168,0],
-"structzyppng_1_1SyncOp.html#afea6bb61a58b97227d8a9dc2cdb67601":[4,0,9,130,0],
-"structzyppng_1_1ThreadData.html":[3,0,13,169],
-"structzyppng_1_1ThreadData.html":[4,0,9,131],
-"structzyppng_1_1ThreadData.html#a2d53989861eb71cc80c24a796744bf90":[3,0,13,169,4],
-"structzyppng_1_1ThreadData.html#a2d53989861eb71cc80c24a796744bf90":[4,0,9,131,4],
-"structzyppng_1_1ThreadData.html#a2e9c5857f61d07c8ece2f07c454b720b":[3,0,13,169,0],
-"structzyppng_1_1ThreadData.html#a2e9c5857f61d07c8ece2f07c454b720b":[4,0,9,131,0],
-"structzyppng_1_1ThreadData.html#a47c9ff3a6623040d0adaeb0054eec63c":[3,0,13,169,7],
-"structzyppng_1_1ThreadData.html#a47c9ff3a6623040d0adaeb0054eec63c":[4,0,9,131,7],
-"structzyppng_1_1ThreadData.html#a5167d394be8e87ead1c8af17f55ce127":[3,0,13,169,2],
-"structzyppng_1_1ThreadData.html#a5167d394be8e87ead1c8af17f55ce127":[4,0,9,131,2],
-"structzyppng_1_1ThreadData.html#a56ad443c0cc46dfbe1ff941231bd6fae":[3,0,13,169,11],
-"structzyppng_1_1ThreadData.html#a56ad443c0cc46dfbe1ff941231bd6fae":[4,0,9,131,11],
-"structzyppng_1_1ThreadData.html#a7b022f937ef20c773eff6d85ba60f4c6":[3,0,13,169,1],
-"structzyppng_1_1ThreadData.html#a7b022f937ef20c773eff6d85ba60f4c6":[4,0,9,131,1],
-"structzyppng_1_1ThreadData.html#a83f579057c289d8c638a3045fa0e982d":[3,0,13,169,3],
-"structzyppng_1_1ThreadData.html#a83f579057c289d8c638a3045fa0e982d":[4,0,9,131,3],
-"structzyppng_1_1ThreadData.html#a88ff6e7987ce1c565994744e29454d38":[3,0,13,169,9],
-"structzyppng_1_1ThreadData.html#a88ff6e7987ce1c565994744e29454d38":[4,0,9,131,9],
-"structzyppng_1_1ThreadData.html#abfe42eb8ed710ad137b0a243b6c4c2fe":[3,0,13,169,6],
-"structzyppng_1_1ThreadData.html#abfe42eb8ed710ad137b0a243b6c4c2fe":[4,0,9,131,6],
-"structzyppng_1_1ThreadData.html#adaf9f1ed041c5b861e9512514c8a2dbe":[3,0,13,169,10],
-"structzyppng_1_1ThreadData.html#adaf9f1ed041c5b861e9512514c8a2dbe":[4,0,9,131,10],
-"structzyppng_1_1ThreadData.html#ae96ac623d52d3cdc89378af18480a3db":[3,0,13,169,5],
-"structzyppng_1_1ThreadData.html#ae96ac623d52d3cdc89378af18480a3db":[4,0,9,131,5],
-"structzyppng_1_1ThreadData.html#aed8aa9fab5bb77503786e2144d6ab2a1":[3,0,13,169,8],
-"structzyppng_1_1ThreadData.html#aed8aa9fab5bb77503786e2144d6ab2a1":[4,0,9,131,8],
-"structzyppng_1_1Transition.html":[3,0,13,172],
-"structzyppng_1_1Transition.html":[4,0,9,134],
-"structzyppng_1_1Transition.html#a09d775d4dac36b0ada90ec59a113f7bb":[3,0,13,172,4],
-"structzyppng_1_1Transition.html#a09d775d4dac36b0ada90ec59a113f7bb":[4,0,9,134,4]
+"structzyppng_1_1SocketPrivate_1_1ConnectingState.html#af49a004a50dcb37b52aae6ce05099e56":[3,0,13,162,3,2]
 };
