@@ -1,5 +1,56 @@
 var NAVTREEINDEX134 =
 {
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#ac7169f1ca12b0205cde87c2fee9dd844":[4,0,9,1,52,2],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#acb09daead5ac798f740cc21b4685199d":[3,0,13,15,52,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#acb09daead5ac798f740cc21b4685199d":[4,0,9,1,52,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#af9a1b1b6fdad0f26ac02d94e5c6d6110":[3,0,13,15,52,1],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#af9a1b1b6fdad0f26ac02d94e5c6d6110":[4,0,9,1,52,1],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html":[3,0,13,15,51],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html":[4,0,9,1,51],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#a32d23b4ce87bf2527923b02d55820804":[3,0,13,15,51,2],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#a32d23b4ce87bf2527923b02d55820804":[4,0,9,1,51,2],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa1d9b1a569233b0dba0a1d2e7227b035":[3,0,13,15,51,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa1d9b1a569233b0dba0a1d2e7227b035":[4,0,9,1,51,5],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa419ee11f494159cddd1eeccb34c532c":[3,0,13,15,51,7],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa419ee11f494159cddd1eeccb34c532c":[4,0,9,1,51,7],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ab8db9840a5595d0d560bfc79598e5ad4":[3,0,13,15,51,3],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ab8db9840a5595d0d560bfc79598e5ad4":[4,0,9,1,51,3],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac09b48c9cfe5e00bfd6376fd24a3fded":[3,0,13,15,51,6],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac09b48c9cfe5e00bfd6376fd24a3fded":[4,0,9,1,51,6],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac146358fa4b635eb08959d5a6879d425":[3,0,13,15,51,1],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac146358fa4b635eb08959d5a6879d425":[4,0,9,1,51,1],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ad66ae9187acf00043802004548108050":[3,0,13,15,51,4],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ad66ae9187acf00043802004548108050":[4,0,9,1,51,4],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#af9f709b06dbe39fe97bf3b8e5b57a2c4":[3,0,13,15,51,0],
+"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#af9f709b06dbe39fe97bf3b8e5b57a2c4":[4,0,9,1,51,0],
+"structzyppng_1_1detail_1_1StateWithTransitions.html":[3,0,13,15,57],
+"structzyppng_1_1detail_1_1StateWithTransitions.html":[4,0,9,1,57],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a03066d5bea4d646de8c52ec93b63508e":[3,0,13,15,57,8],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a03066d5bea4d646de8c52ec93b63508e":[4,0,9,1,57,8],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a060bb78f8cf3fb07e67ef3e7907d3366":[3,0,13,15,57,6],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a060bb78f8cf3fb07e67ef3e7907d3366":[4,0,9,1,57,6],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a3b6da1e664f87f06cf85138e3a0340c3":[3,0,13,15,57,12],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a3b6da1e664f87f06cf85138e3a0340c3":[4,0,9,1,57,12],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a5f16139fc99297dedbd601974a5e7364":[3,0,13,15,57,11],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a5f16139fc99297dedbd601974a5e7364":[4,0,9,1,57,11],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a76bd5314f289389883d249c13d4e5911":[3,0,13,15,57,5],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a76bd5314f289389883d249c13d4e5911":[4,0,9,1,57,5],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a96591d2f6f95e0c4f78c68a06bf6e570":[3,0,13,15,57,2],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a96591d2f6f95e0c4f78c68a06bf6e570":[4,0,9,1,57,2],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a97c8053a141fc89e40ccfbb13ae9520d":[3,0,13,15,57,9],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a97c8053a141fc89e40ccfbb13ae9520d":[4,0,9,1,57,9],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a9d1dee8e76c55375ba632570fc1844c8":[3,0,13,15,57,14],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a9d1dee8e76c55375ba632570fc1844c8":[4,0,9,1,57,14],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a9e3c50bcd0425589e7bd7dc2a76aa0ec":[3,0,13,15,57,4],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#a9e3c50bcd0425589e7bd7dc2a76aa0ec":[4,0,9,1,57,4],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#ad09bdcf83fbb3058bddf230b37f1d3c2":[3,0,13,15,57,10],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#ad09bdcf83fbb3058bddf230b37f1d3c2":[4,0,9,1,57,10],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#adc86f18c353d52176ed41f71f2da6279":[3,0,13,15,57,3],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#adc86f18c353d52176ed41f71f2da6279":[4,0,9,1,57,3],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#aecccf1f0ef718ce2d9f71fa1cfde7859":[3,0,13,15,57,1],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#aecccf1f0ef718ce2d9f71fa1cfde7859":[4,0,9,1,57,1],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#af39388007b832bd0f3559ac97f82dff7":[3,0,13,15,57,7],
+"structzyppng_1_1detail_1_1StateWithTransitions.html#af39388007b832bd0f3559ac97f82dff7":[4,0,9,1,57,7],
 "structzyppng_1_1detail_1_1StateWithTransitions.html#af40ee8bbd820a0efa83f540cedeb7cb4":[3,0,13,15,57,0],
 "structzyppng_1_1detail_1_1StateWithTransitions.html#af40ee8bbd820a0efa83f540cedeb7cb4":[4,0,9,1,57,0],
 "structzyppng_1_1detail_1_1StateWithTransitions.html#afe587fbad7ef0c87a45da08b5c35648b":[3,0,13,15,57,13],
@@ -198,56 +249,5 @@ var NAVTREEINDEX134 =
 "structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html":[4,0,9,1,45],
 "structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#a228e8c11e6c55e0096a648d794d3ada5":[3,0,13,15,45,1],
 "structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#a228e8c11e6c55e0096a648d794d3ada5":[4,0,9,1,45,1],
-"structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#aac7b198dfab2fd980ab147cc142270fe":[3,0,13,15,45,0],
-"structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#aac7b198dfab2fd980ab147cc142270fe":[4,0,9,1,45,0],
-"structzyppng_1_1detail_1_1mtry__helper.html":[3,0,13,15,47],
-"structzyppng_1_1detail_1_1mtry__helper.html":[4,0,9,1,47],
-"structzyppng_1_1detail_1_1mtry__helper.html#a2f47fe87f6daeac798ef2b1b95d1ad8d":[3,0,13,15,47,1],
-"structzyppng_1_1detail_1_1mtry__helper.html#a2f47fe87f6daeac798ef2b1b95d1ad8d":[4,0,9,1,47,1],
-"structzyppng_1_1detail_1_1mtry__helper.html#abc9382babbe0de1f63ea0d103104930f":[3,0,13,15,47,0],
-"structzyppng_1_1detail_1_1mtry__helper.html#abc9382babbe0de1f63ea0d103104930f":[4,0,9,1,47,0],
-"structzyppng_1_1detail_1_1or__else__helper.html":[3,0,13,15,48],
-"structzyppng_1_1detail_1_1or__else__helper.html":[4,0,9,1,48],
-"structzyppng_1_1detail_1_1or__else__helper.html#a179fd1e8d51de8c8d4ada28c07d01658":[3,0,13,15,48,0],
-"structzyppng_1_1detail_1_1or__else__helper.html#a179fd1e8d51de8c8d4ada28c07d01658":[4,0,9,1,48,0],
-"structzyppng_1_1detail_1_1or__else__helper.html#a6c8ad53ee2f67c3e7ad7ee9af5a51a0d":[3,0,13,15,48,2],
-"structzyppng_1_1detail_1_1or__else__helper.html#a6c8ad53ee2f67c3e7ad7ee9af5a51a0d":[4,0,9,1,48,2],
-"structzyppng_1_1detail_1_1or__else__helper.html#ab981e6614a33c76fd2ff2d14a6893e37":[3,0,13,15,48,1],
-"structzyppng_1_1detail_1_1or__else__helper.html#ab981e6614a33c76fd2ff2d14a6893e37":[4,0,9,1,48,1],
-"structzyppng_1_1detail_1_1showme.html":[3,0,13,15,56],
-"structzyppng_1_1detail_1_1showme.html":[4,0,9,1,56],
-"structzyppng_1_1detail_1_1transform__collect__helper.html":[3,0,13,15,58],
-"structzyppng_1_1detail_1_1transform__collect__helper.html":[4,0,9,1,58],
-"structzyppng_1_1detail_1_1transform__collect__helper.html#a7fe0501f514f72c6c4005bc17e410fa2":[3,0,13,15,58,0],
-"structzyppng_1_1detail_1_1transform__collect__helper.html#a7fe0501f514f72c6c4005bc17e410fa2":[4,0,9,1,58,0],
-"structzyppng_1_1detail_1_1transform__collect__helper.html#aea280732fe5919a95678060fe012d1e2":[3,0,13,15,58,1],
-"structzyppng_1_1detail_1_1transform__collect__helper.html#aea280732fe5919a95678060fe012d1e2":[4,0,9,1,58,1],
-"structzyppng_1_1detail_1_1transform__helper.html":[3,0,13,15,59],
-"structzyppng_1_1detail_1_1transform__helper.html":[4,0,9,1,59],
-"structzyppng_1_1detail_1_1transform__helper.html#a73ba8c47636e57a8aee235ebd977a174":[3,0,13,15,59,0],
-"structzyppng_1_1detail_1_1transform__helper.html#a73ba8c47636e57a8aee235ebd977a174":[4,0,9,1,59,0],
-"structzyppng_1_1detail_1_1transform__helper.html#ad95da508f4270beb9af35b2067fce65a":[3,0,13,15,59,1],
-"structzyppng_1_1detail_1_1transform__helper.html#ad95da508f4270beb9af35b2067fce65a":[4,0,9,1,59,1],
-"structzyppng_1_1function__traits.html":[3,0,13,81],
-"structzyppng_1_1function__traits.html":[4,0,9,43],
-"structzyppng_1_1function__traits_3_01F_00_01std_1_1void__t_3_01decltype_07_6F_1_1operator_07_08_08_4_01_4.html":[3,0,13,82],
-"structzyppng_1_1function__traits_3_01F_00_01std_1_1void__t_3_01decltype_07_6F_1_1operator_07_08_08_4_01_4.html":[4,0,9,44],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4.html":[3,0,13,85],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4.html":[4,0,9,47],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4.html#a6e2dfd7664957756f399fad928b859ad":[3,0,13,85,1],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4.html#a6e2dfd7664957756f399fad928b859ad":[4,0,9,47,1],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4.html#ab5d32607b3fb9d3f8f831f08c21411fa":[3,0,13,85,2],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4.html#ab5d32607b3fb9d3f8f831f08c21411fa":[4,0,9,47,2],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4_1_1argument.html":[3,0,13,85,0],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4_1_1argument.html":[4,0,9,47,0],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4_1_1argument.html#ae950ca91abd06dd015a28a7c3fb1ede6":[3,0,13,85,0,0],
-"structzyppng_1_1function__traits_3_01R_07Args_8_8_8_08_4_1_1argument.html#ae950ca91abd06dd015a28a7c3fb1ede6":[4,0,9,47,0,0],
-"structzyppng_1_1function__traits_3_01R_07C_1_1_5_08_07Args_8_8_8_08_01const_01_4.html":[3,0,13,86],
-"structzyppng_1_1function__traits_3_01R_07C_1_1_5_08_07Args_8_8_8_08_01const_01_4.html":[4,0,9,48],
-"structzyppng_1_1function__traits_3_01R_07C_1_1_5_08_07Args_8_8_8_08_4.html":[3,0,13,87],
-"structzyppng_1_1function__traits_3_01R_07C_1_1_5_08_07Args_8_8_8_08_4.html":[4,0,9,49],
-"structzyppng_1_1function__traits_3_01R_07C_1_1_5_08_4.html":[3,0,13,88],
-"structzyppng_1_1function__traits_3_01R_07C_1_1_5_08_4.html":[4,0,9,50],
-"structzyppng_1_1function__traits_3_01R_07_5_08_07Args_8_8_8_08_4.html":[3,0,13,84],
-"structzyppng_1_1function__traits_3_01R_07_5_08_07Args_8_8_8_08_4.html":[4,0,9,46]
+"structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#aac7b198dfab2fd980ab147cc142270fe":[3,0,13,15,45,0]
 };
