@@ -1,5 +1,7 @@
 var NAVTREEINDEX66 =
 {
+"classzypp_1_1sat_1_1WhatProvides.html#a89ff5dd3eb0b72a33e0a41d5c2c03cd5":[3,0,10,37,19,5],
+"classzypp_1_1sat_1_1WhatProvides.html#a89ff5dd3eb0b72a33e0a41d5c2c03cd5":[4,0,7,31,20,5],
 "classzypp_1_1sat_1_1WhatProvides.html#aa1be7f478135018a55ad7fb930c9b814":[3,0,10,37,19,6],
 "classzypp_1_1sat_1_1WhatProvides.html#aa1be7f478135018a55ad7fb930c9b814":[4,0,7,31,20,6],
 "classzypp_1_1sat_1_1WhatProvides.html#abd0e1ecb16305c9b0b8a7ffa829a5d16":[3,0,10,37,19,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX66 =
 "classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a2cde750308ee4c4cc9816944138303ac":[4,0,7,31,0,4,3],
 "classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a3bba403ca1429a6ea155faea3031ac5e":[3,0,10,37,0,4,1],
 "classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a3bba403ca1429a6ea155faea3031ac5e":[4,0,7,31,0,4,1],
-"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5c1d521b119ca31cf7c31029727734c3":[3,0,10,37,0,4,0],
-"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5c1d521b119ca31cf7c31029727734c3":[4,0,7,31,0,4,0],
-"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5e0af634204b84a9a91e5d922c64a87d":[3,0,10,37,0,4,5]
+"classzypp_1_1sat_1_1detail_1_1Transaction__const__iterator.html#a5c1d521b119ca31cf7c31029727734c3":[3,0,10,37,0,4,0]
 };
