@@ -1,5 +1,7 @@
 var NAVTREEINDEX91 =
 {
+"classzyppng_1_1SyncMediaHandle.html#aefb359567dac1af8e3aeec8cc4d7f04c":[4,0,9,129,8],
+"classzyppng_1_1SyncMediaHandle.html#af97b7da81697db61ebea7108fcd0da26":[3,0,13,167,2],
 "classzyppng_1_1SyncMediaHandle.html#af97b7da81697db61ebea7108fcd0da26":[4,0,9,129,2],
 "classzyppng_1_1Timer.html":[3,0,13,170],
 "classzyppng_1_1Timer.html":[4,0,9,132],
@@ -247,7 +249,5 @@ var NAVTREEINDEX91 =
 "classzyppng_1_1WorkerCaps.html#ad0d2a368079aa367ce42a0e7bc4595db":[4,0,9,143,18],
 "classzyppng_1_1WorkerCaps.html#ad4481358c39ce9bfea621d0cd002e1dc":[3,0,13,181,22],
 "classzyppng_1_1WorkerCaps.html#ad4481358c39ce9bfea621d0cd002e1dc":[4,0,9,143,22],
-"classzyppng_1_1WorkerCaps.html#adb4dd61ccb3049067d090e93bc20f980":[3,0,13,181,17],
-"classzyppng_1_1WorkerCaps.html#adb4dd61ccb3049067d090e93bc20f980":[4,0,9,143,17],
-"classzyppng_1_1WorkerCaps.html#aeaace097c6b00f245dc4f4fc0349f6ca":[3,0,13,181,21]
+"classzyppng_1_1WorkerCaps.html#adb4dd61ccb3049067d090e93bc20f980":[3,0,13,181,17]
 };
